==> mx-system-sounds_19.07.02.tar.xz: mx-system-sounds/translations/mx-system-sounds_uk.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="uk" version="2.1">
<context>
    <name>mxsystemsounds</name>
    <message>
        <location filename="mxsystemsounds.ui" line="14"/>
        <location filename="mxsystemsounds.cpp" line="70"/>
        <location filename="mxsystemsounds.cpp" line="288"/>
        <location filename="mxsystemsounds.cpp" line="300"/>
        <location filename="mxsystemsounds.cpp" line="334"/>
        <source>MX System Sounds</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mxsystemsounds.ui" line="48"/>
        <source>Event Sounds</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mxsystemsounds.ui" line="61"/>
        <source>Session Sounds</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mxsystemsounds.ui" line="68"/>
        <source>XFCE Event Sounds</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mxsystemsounds.ui" line="75"/>
        <source>Login</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mxsystemsounds.ui" line="82"/>
        <source>XFCE Input Feedback Sounds</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mxsystemsounds.ui" line="89"/>
        <source>Logout</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mxsystemsounds.ui" line="118"/>
        <source>Custom Sounds</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mxsystemsounds.ui" line="125"/>
        <source>Theme</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mxsystemsounds.ui" line="132"/>
        <location filename="mxsystemsounds.ui" line="153"/>
        <source>Login Sound</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mxsystemsounds.ui" line="139"/>
        <location filename="mxsystemsounds.ui" line="185"/>
        <source>...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mxsystemsounds.ui" line="164"/>
        <location filename="mxsystemsounds.ui" line="207"/>
        <location filename="mxsystemsounds.ui" line="210"/>
        <source>Theme Default</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mxsystemsounds.ui" line="167"/>
        <source>Use Default</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mxsystemsounds.ui" line="178"/>
        <location filename="mxsystemsounds.ui" line="196"/>
        <source>Logout Sound</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mxsystemsounds.ui" line="229"/>
        <source>Borealis</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mxsystemsounds.ui" line="260"/>
        <source>About this application</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mxsystemsounds.ui" line="263"/>
        <source>About...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mxsystemsounds.ui" line="270"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="mxsystemsounds.ui" line="286"/>
        <source>Display help </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mxsystemsounds.ui" line="289"/>
        <source>Help</source>
        <translation>Довідка</translation>
    </message>
    <message>
        <location filename="mxsystemsounds.ui" line="296"/>
        <source>Alt+H</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mxsystemsounds.ui" line="354"/>
        <source>Apply</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mxsystemsounds.ui" line="380"/>
        <source>Quit application</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mxsystemsounds.ui" line="383"/>
        <source>Close</source>
        <translation>Закрити</translation>
    </message>
    <message>
        <location filename="mxsystemsounds.ui" line="390"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="mxsystemsounds.cpp" line="287"/>
        <source>About MX System Sounds</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mxsystemsounds.cpp" line="288"/>
        <source>Version: </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mxsystemsounds.cpp" line="289"/>
        <source>Configure Event &amp; Session Sounds</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mxsystemsounds.cpp" line="291"/>
        <source>Copyright (c) MX Linux</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mxsystemsounds.cpp" line="292"/>
        <location filename="mxsystemsounds.cpp" line="300"/>
        <source>License</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mxsystemsounds.cpp" line="293"/>
        <source>Changelog</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mxsystemsounds.cpp" line="294"/>
        <source>Cancel</source>
        <translation>Скасувати</translation>
    </message>
    <message>
        <location filename="mxsystemsounds.cpp" line="309"/>
        <source>&amp;Close</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mxsystemsounds.cpp" line="353"/>
        <location filename="mxsystemsounds.cpp" line="383"/>
        <source>Select Sound File</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mxsystemsounds.cpp" line="353"/>
        <location filename="mxsystemsounds.cpp" line="383"/>
        <source>Sound Files (*.mp3 *.m4a *.aac *.flac *.ogg *.oga *.wav)</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> mx-system-sounds_19.8.03.tar.xz: mx-system-sounds/translations/mx-system-sounds_uk.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="uk" version="2.1">
<context>
    <name>mxsystemsounds</name>
    <message>
        <location filename="mxsystemsounds.ui" line="14"/>
        <location filename="mxsystemsounds.cpp" line="70"/>
        <location filename="mxsystemsounds.cpp" line="288"/>
        <location filename="mxsystemsounds.cpp" line="300"/>
        <location filename="mxsystemsounds.cpp" line="334"/>
        <source>MX System Sounds</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mxsystemsounds.ui" line="48"/>
        <source>Event Sounds</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mxsystemsounds.ui" line="61"/>
        <source>Session Sounds</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mxsystemsounds.ui" line="68"/>
        <source>XFCE Event Sounds</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mxsystemsounds.ui" line="75"/>
        <source>Login</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mxsystemsounds.ui" line="82"/>
        <source>XFCE Input Feedback Sounds</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mxsystemsounds.ui" line="89"/>
        <source>Logout</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mxsystemsounds.ui" line="118"/>
        <source>Custom Sounds</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mxsystemsounds.ui" line="125"/>
        <source>Theme</source>
        <translation>Тема</translation>
    </message>
    <message>
        <location filename="mxsystemsounds.ui" line="132"/>
        <location filename="mxsystemsounds.ui" line="153"/>
        <source>Login Sound</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mxsystemsounds.ui" line="139"/>
        <location filename="mxsystemsounds.ui" line="185"/>
        <source>...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mxsystemsounds.ui" line="164"/>
        <location filename="mxsystemsounds.ui" line="207"/>
        <location filename="mxsystemsounds.ui" line="210"/>
        <source>Theme Default</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mxsystemsounds.ui" line="167"/>
        <source>Use Default</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mxsystemsounds.ui" line="178"/>
        <location filename="mxsystemsounds.ui" line="196"/>
        <source>Logout Sound</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mxsystemsounds.ui" line="229"/>
        <source>Borealis</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mxsystemsounds.ui" line="260"/>
        <source>About this application</source>
        <translation>Про цю програму</translation>
    </message>
    <message>
        <location filename="mxsystemsounds.ui" line="263"/>
        <source>About...</source>
        <translation>Про...</translation>
    </message>
    <message>
        <location filename="mxsystemsounds.ui" line="270"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="mxsystemsounds.ui" line="286"/>
        <source>Display help </source>
        <translation>Показати довідку</translation>
    </message>
    <message>
        <location filename="mxsystemsounds.ui" line="289"/>
        <source>Help</source>
        <translation>Довідка</translation>
    </message>
    <message>
        <location filename="mxsystemsounds.ui" line="296"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="mxsystemsounds.ui" line="354"/>
        <source>Apply</source>
        <translation>Застосувати</translation>
    </message>
    <message>
        <location filename="mxsystemsounds.ui" line="380"/>
        <source>Quit application</source>
        <translation>Закрити програму</translation>
    </message>
    <message>
        <location filename="mxsystemsounds.ui" line="383"/>
        <source>Close</source>
        <translation>Закрити</translation>
    </message>
    <message>
        <location filename="mxsystemsounds.ui" line="390"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="mxsystemsounds.cpp" line="287"/>
        <source>About MX System Sounds</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mxsystemsounds.cpp" line="288"/>
        <source>Version: </source>
        <translation>Версія:</translation>
    </message>
    <message>
        <location filename="mxsystemsounds.cpp" line="289"/>
        <source>Configure Event &amp; Session Sounds</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mxsystemsounds.cpp" line="291"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="mxsystemsounds.cpp" line="292"/>
        <location filename="mxsystemsounds.cpp" line="300"/>
        <source>License</source>
        <translation>Ліцензія</translation>
    </message>
    <message>
        <location filename="mxsystemsounds.cpp" line="293"/>
        <source>Changelog</source>
        <translation>Список змін</translation>
    </message>
    <message>
        <location filename="mxsystemsounds.cpp" line="294"/>
        <source>Cancel</source>
        <translation>Скасувати</translation>
    </message>
    <message>
        <location filename="mxsystemsounds.cpp" line="309"/>
        <source>&amp;Close</source>
        <translation>&amp;Закрити</translation>
    </message>
    <message>
        <location filename="mxsystemsounds.cpp" line="353"/>
        <location filename="mxsystemsounds.cpp" line="383"/>
        <source>Select Sound File</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mxsystemsounds.cpp" line="353"/>
        <location filename="mxsystemsounds.cpp" line="383"/>
        <source>Sound Files (*.mp3 *.m4a *.aac *.flac *.ogg *.oga *.wav)</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
